@@ -1,19 +1,19 @@
-import os
-import base64
-import aiohttp
 import asyncio
-import ujson as json
-from uuid import UUID
-from .sockets import Wss
+import os
 from binascii import hexlify
-from typing import BinaryIO, Union
 from time import time as timestamp
+from typing import BinaryIO, Union
+from uuid import UUID
 
+import aiohttp
+import ujson as json
+
+from .sockets import Wss
 from ..lib import *
 from ..lib.objects import *
 
 
-class SClient(Wss):
+class SClient(Wss, Headers):
     def __init__(self, deviceId: str = None, Trace: bool = False):
         self.uid = None
         self.sid = None
@@ -21,11 +21,13 @@ class SClient(Wss):
         self.web_headers = None
 
         self.Trace = Trace
-        headers.deviceId = deviceId
+        headers.staticDevice = deviceId
+
+        Headers.__init__(self)
         Wss.__init__(self, client=self, Session=self.session, Trace=self.Trace)
         
-        self.deviceId = headers.Headers().deviceId
-        self.headers = headers.Headers().headers
+        self.deviceId = self.headers_device
+        self.headers = self.app_headers
         self.session = aiohttp.ClientSession()
 
     async def __aenter__(self) -> "SClient":
@@ -44,23 +46,16 @@ class SClient(Wss):
     async def _close_session(self):
         await self.session.close()
 
-    def change_lang(self, lang: str = "ar-SY"):
-        headers.lang = lang
-        self.headers = headers.Headers().headers
-
     async def sid_login(self, sid: str):
-        if "sid=" not in sid: headers.sid = f"sid={sid}"
-        else: headers.sid = sid
-        self.headers = headers.Headers().headers
+        finalSessionId = sid if "sid=" in sid else f"sid={sid}"
 
-        try:
-            info = (await self.get_account_info()).userId
-            self.uid = info
-            self.sid = headers.sid
-            headers.uid = self.uid
-            await self.Start()
-            return info
-        except Exception as e: print(f"\nError -- getting user info in sid_login: {e}\n")
+        info = (await self.get_account_info())
+        self.uid = info.userId
+        self.sid = finalSessionId
+        headers.userId = self.uid
+        headers.definedSession = self.sid
+        await self.Start()
+        return info
 
     async def login(self, email: str = None, password: str = None, secret: str = None,socket: bool = False):
         data = {
@@ -70,32 +65,26 @@ class SClient(Wss):
             "v": 2,
             "timestamp": int(timestamp() * 1000)
         }
+        print(self.headers["NDCDEVICEID"])
 
-        ## - email n pass or secret login hanlder
-        if password:
-            if email:
-                data["email"] = email
-                data["secret"] = f"0 {password}"
-            else: raise ValueError("When using password email is required when using secret email is not required so please insert email with password")
+        if password and email and not secret:
+            data["email"] = email
+            data["secret"] = f"0 {password}"
         elif secret: data["secret"] = secret
-        else: raise TypeError("Please consider inserting email and password or secret")
+        else: raise ValueError("Please provide VALID login info")
 
         data = json.dumps(data)
-        async with self.session.post(api(f"/g/s/auth/login"), headers=headers.Headers(data=data).headers, data=data) as req:
-            if req.status != 200:
-                return CheckExceptions(await req.json())
-            else:
-                self.sid = f'sid={(await req.json())["sid"]}'
-                self.uid = (await req.json())["auid"]
-                self.headers["NDCAUTH"] = self.sid
-                self.secret = (await req.json())["secret"]
-                headers.sid = self.sid
-                headers.uid = self.uid
-                self.headers = headers.Headers().headers
-                self.web_headers = headers.Headers().web_headers
-                if socket: self.Launch()
-                else: pass
-                return Login(await req.json())
+        async with self.session.post(api(f"/g/s/auth/login"), headers=self.updateHeaders(data=data), data=data) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+        
+            self.sid = f'sid={(await req.json())["sid"]}'
+            self.secret = (await req.json())["secret"]
+            self.uid = (await req.json())["auid"]
+            headers.definedSession = self.sid
+            headers.userId = self.uid
+
+            if socket: self.Launch()
+            return Login(await req.json())
 
     async def logout(self):
         data = json.dumps({
@@ -104,17 +93,15 @@ class SClient(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        async with self.session.post(api("/g/s/auth/logout"), headers=headers.Headers(data=data).headers, data=data ) as req:
-            if req.status != 200:
-                return CheckExceptions(await req.json())
-            else:
-                self.sid = None
-                self.uid = None
-                headers.sid = None
-                headers.uid = None
-                if self.Ran:await self.close()
-                else:pass
-                return Json((await req.json()))
+        async with self.session.post(api("/g/s/auth/logout"), headers=self.updateHeaders(data=data), data=data ) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            
+            self.sid = None
+            self.uiduserIdNone
+            headers.uid = None
+
+            if self.Ran:await self.close()
+            return Json((await req.json()))
 
     async def check_device(self, deviceId: str):
         data = json.dumps({
@@ -122,9 +109,9 @@ class SClient(Wss):
             "timestamp": int(timestamp() * 1000),
             "clientType": 100
         })
-        async with self.session.post(api(f"/g/s/device"), headers=headers.Headers(data=data).headers, data=data) as req:
+        async with self.session.post(api(f"/g/s/device"), headers=self.updateHeaders(data=data), data=data) as req:
             if (await req.json())["api:statuscode"] != 0: return CheckExceptions(await req.json())
-            else: return f"api:message {(await req.json())['api:message']}\napi:statuscode {(await req.json())['api:statuscode']}\nThe device is fine"
+            return f"api:message {(await req.json())['api:message']}\napi:statuscode {(await req.json())['api:statuscode']}\nThe device is fine"
 
     async def upload_image(self, image: BinaryIO):
         data = image.read()
@@ -132,7 +119,7 @@ class SClient(Wss):
         self.headers["content-type"] = "image/jpg"
         self.headers["content-length"] = str(len(data))
 
-        async with self.session.post(api(f"/g/s/media/upload"), data=data, headers=self.headers ) as req:
+        async with self.session.post(api(f"/g/s/media/upload"), data=data, headers=self.headers) as req:
             return (await req.json())["mediaValue"]
 
     async def send_verify(self, email: str):
@@ -142,7 +129,7 @@ class SClient(Wss):
             "deviceID": self.deviceId,
             "timestamp": int(timestamp() * 1000)
         })
-        async with self.session.post(api(f"/g/s/auth/request-security-validation"), headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/auth/request-security-validation"), headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -158,7 +145,7 @@ class SClient(Wss):
             "data": {"code": code},
             "deviceID": self.deviceId
         })
-        async with self.session.post(api(f"/g/s/auth/activate-email"), headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/auth/activate-email"), headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -170,7 +157,7 @@ class SClient(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        async with self.session.post(api(f"/g/s/account/delete-request/cancel"), headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/account/delete-request/cancel"), headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -181,7 +168,7 @@ class SClient(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        async with self.session.post(api(f"/g/s/account/delete-request"), headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/account/delete-request"), headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -197,7 +184,7 @@ class SClient(Wss):
 
     async def change_amino_id(self, aminoId: str = None):
         data = json.dumps({"aminoId": aminoId, "timestamp": int(timestamp() * 1000)})
-        async with self.session.post(api(f"/g/s/account/change-amino-id"), data=data, headers=headers.Headers(data=data).headers ) as req:
+        async with self.session.post(api(f"/g/s/account/change-amino-id"), data=data, headers=self.updateHeaders(data=data) ) as req:
             if req.status != 200: return CheckExceptions(((await req.json())))
             return Json(((await req.json())))
 
@@ -227,12 +214,8 @@ class SClient(Wss):
             return Json(((await req.json())))
 
     async def start_chat(self, userId: Union[str, list], title: str = None, message: str = None, content: str = None,chatType: int = 0):
-        if type(userId) is list:
-            userIds = userId
-        elif type(userId) is str:
-            userIds = [userId]
-        else:
-            raise TypeError("Please put a str or list of userId")
+        if type(userId) is list: userIds = userId
+        elif type(userId) is str: userIds = [userId]
 
         data = json.dumps({
             "title": title,
@@ -243,7 +226,7 @@ class SClient(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        async with self.session.post(api(f"/g/s/chat/thread"), headers=headers.Headers(data=data).headers,data=data) as req:
+        async with self.session.post(api(f"/g/s/chat/thread"), headers=self.updateHeaders(data=data),data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -267,16 +250,13 @@ class SClient(Wss):
         if icon: data["icon"] = self.upload_image(icon)
         if content: data["content"] = content
         if backgroundColor: data["extensions"]["style"] = {"backgroundColor": backgroundColor}
-        if backgroundImage: data["extensions"]["style"] = {
-            "backgroundMediaList": [[100, backgroundImage, None, None, None]]}
+        if backgroundImage: data["extensions"]["style"] = {"backgroundMediaList": [[100, backgroundImage, None, None, None]]}
         if defaultBubbleId: data["extensions"] = {"async defaultBubbleId": defaultBubbleId}
 
         data = json.dumps(data)
-        async with self.session.post(api(f"/g/s/user-profile/{self.uid}"), headers=headers.Headers(data=data).headers , data=data) as req:
-            if req.status != 200:
-                return CheckExceptions(await req.json())
-            else:
-                return Json((await req.json()))
+        async with self.session.post(api(f"/g/s/user-profile/{self.uid}"), headers=self.updateHeaders(data=data) , data=data) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json((await req.json()))
 
     async def flag_community(self, comId: str, reason: str, flagType: int):
         data = json.dumps({
@@ -286,7 +266,7 @@ class SClient(Wss):
             "message": reason,
             "timestamp": int(timestamp() * 1000)
         })
-        async with self.session.post(api(f"/x{comId}/s/g-flag"), headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/x{comId}/s/g-flag"), headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -299,7 +279,7 @@ class SClient(Wss):
         data = {"timestamp": int(timestamp() * 1000)}
         if InviteId: data["invitationId"] = InviteId
         data = json.dumps(data)
-        async with self.session.post(api(f"/x{comId}/s/community/join"), headers=headers.Headers(data=data).headers, data=data) as req:
+        async with self.session.post(api(f"/x{comId}/s/community/join"), headers=self.updateHeaders(data=data), data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -310,7 +290,7 @@ class SClient(Wss):
             "message": reason,
             "timestamp": int(timestamp() * 1000)
         }
-
+        
         if type in types:
             data["flagType"] = types[type]
 
@@ -325,10 +305,9 @@ class SClient(Wss):
         elif wikiId:
             data["objectId"] = wikiId
             data["objectType"] = 2
-        else: raise TypeError("choose a certain type to report")
 
         data = json.dumps(data)
-        async with self.session.post(api(f"/g/s/flag", headers=headers.Headers(data=data).headers, data=data)) as req:
+        async with self.session.post(api(f"/g/s/flag"), headers=self.updateHeaders(data=data), data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             else: return Json(await req.json())
 
@@ -338,17 +317,20 @@ class SClient(Wss):
             return Json((await req.json()))
 
     async def follow(self, userId: Union[str, list]):
-        if type(userId) is str:
-            async with self.session.post(api(f"/g/s/user-profile/{userId}/member"), headers=self.headers ) as req:
-                if req.status != 200: return CheckExceptions(await req.json())
-                return Json((await req.json()))
+        data = {
+            "timestamp": int(timestamp() * 1000)
+        }
+
+        if type(userId) is str: url = f"/g/s/user-profile/{userId}/member"
         elif type(userId) is list:
-            data = json.dumps({"targetUidList": userId, "timestamp": int(timestamp() * 1000)})
-            async with self.session.post(api(f"/g/s/user-profile/{self.uid}/joined"),headers=headers.Headers(data=data).headers , data=data) as req:
-                if req.status != 200: return CheckExceptions(await req.json())
-                return Json((await req.json()))
-        else:
-            raise TypeError("Please put a str or list of userId")
+            url = f"/g/s/user-profile/{self.uid}/joined"
+            data["targetUidList"] = userId
+        
+        data = json.dumps(data)
+        async with self.session.post(api(url),headers=self.updateHeaders(data=data), data=data) as req:
+            if req.status != 200: return CheckExceptions(await req.json())
+            return Json((await req.json()))
+
 
     async def get_member_following(self, userId: str, start: int = 0, size: int = 25):
         async with self.session.get(api(f"/g/s/user-profile/{userId}/joined?start={start}&size={size}"), headers=self.headers ) as req:
@@ -478,7 +460,7 @@ class SClient(Wss):
             data["extensions"] = None
 
         data = json.dumps(data)
-        async with self.session.post(api(f"/g/s/chat/thread/{chatId}/message"),headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/chat/thread/{chatId}/message"),headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -527,7 +509,7 @@ class SClient(Wss):
         else:
             raise TypeError("please put chat or blog Id")
 
-        async with self.session.post(url, headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(url, headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -550,7 +532,7 @@ class SClient(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        async with self.session.post(api(f"/g/s/auth/reset-password"), headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/auth/reset-password"), headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -561,7 +543,7 @@ class SClient(Wss):
             "validationContext": None,
             "deviceID": self.deviceId
         })
-        header = headers.Headers(data=data).headers
+        header = self.updateHeaders(data=data)
         header["ndcdeviceid"], header["ndcauth"] = header["NDCDEVICEID"], header["NDCAUTH"]
         async with self.session.post(api("/g/s/auth/change-password"), headers=header, data=data) as req:
             if req.status != 200:
@@ -587,7 +569,7 @@ class SClient(Wss):
 
         data = json.dumps(data)
 
-        async with self.session.post(api(f"/g/s/user-profile/{userId}/g-comment"), headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/user-profile/{userId}/g-comment"), headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -599,7 +581,7 @@ class SClient(Wss):
     async def invite_by_host(self, chatId: str, userId: Union[str, list]):
         data = json.dumps({"uidList": userId, "timestamp": int(timestamp() * 1000)})
 
-        async with self.session.post(api(f"/g/s/chat/thread/{chatId}/avchat-members"),headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/chat/thread/{chatId}/avchat-members"),headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -657,7 +639,7 @@ class SClient(Wss):
 
     async def invite_to_voice_chat(self, userId: str = None, chatId: str = None):
         data = json.dumps({"uid": userId, "timestamp": int(timestamp() * 1000)})
-        async with self.session.post(api(f"/g/s/chat/thread/{chatId}/vvchat-presenter/invite"),headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(api(f"/g/s/chat/thread/{chatId}/vvchat-presenter/invite"),headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -693,7 +675,7 @@ class SClient(Wss):
         elif comId is not None:url = api(f"/g/s-x{comId}/link-resolution")
         else:raise TypeError("please put a comId")
 
-        async with self.session.post(url, headers=headers.Headers(data=data).headers , data=data) as req:
+        async with self.session.post(url, headers=self.updateHeaders(data=data) , data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return FromCode((await req.json())["linkInfoV2"]["extensions"]["linkInfo"]).FromCode
 
@@ -707,7 +689,7 @@ class SClient(Wss):
                 raise TypeError("Do not disturb should be True or False")
 
             data = json.dumps({"alertOption": opt, "timestamp": int(timestamp() * 1000)})
-            async with self.session.post(api(f"/g/s/chat/thread/{chatId}/member/{self.uid}/alert"), data=data,headers=headers.Headers(data=data).headers ) as req:
+            async with self.session.post(api(f"/g/s/chat/thread/{chatId}/member/{self.uid}/alert"), data=data,headers=self.updateHeaders(data=data) ) as req:
                 if req.status != 200: return CheckExceptions(await req.json())
                 res.append(Json((await req.json())))
 
@@ -767,7 +749,7 @@ class SClient(Wss):
         else:
             raise TypeError("Please put blogId or wikiId")
 
-        async with self.session.post(url, data=data, headers=headers.Headers(data=data).headers ) as req:
+        async with self.session.post(url, data=data, headers=self.updateHeaders(data=data) ) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -801,7 +783,7 @@ class SClient(Wss):
             "timestamp": int(timestamp() * 1000)
         })
 
-        async with self.session.post(api(f"/g/s/auth/register"), data=data, headers=headers.Headers(data=data).headers ) as req:
+        async with self.session.post(api(f"/g/s/auth/register"), data=data, headers=self.updateHeaders(data=data) ) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
@@ -813,7 +795,7 @@ class SClient(Wss):
     async def edit_comment(self, commentId: str, comment: str, userId: str):
         data = {"content": comment, "timestamp": int(timestamp() * 1000)}
         data = json.dumps(data)
-        async with self.session.post(api(f"/g/s/user-profile/{userId}/comment/{commentId}"), data=data, headers=headers.Headers(data=data).headers) as req:
+        async with self.session.post(api(f"/g/s/user-profile/{userId}/comment/{commentId}"), data=data, headers=self.updateHeaders(data=data)) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Comment(await req.json()).Comments
 
