@@ -4,9 +4,8 @@
 import threading
 import time as timer
 from sys import _getframe as getframe
-from typing import Union, BinaryIO
+from typing import Union
 
-import requests
 import ujson as json
 import websocket
 
@@ -21,7 +20,7 @@ class Callbacks:
         self.methods = {
             10: self._resolve_payload,
             400: self._resolve_topics,
-            1000: self._resolve_chat_message
+            1000: self._resolve_chat_message,
         }
 
         self.chat_methods = {
@@ -74,13 +73,13 @@ class Callbacks:
             "129:0": self.on_chat_tipping_disabled,
             "65281:0": self.on_timestamp_message,
             "65282:0": self.on_welcome_message,
-            "65283:0": self.on_invite_message
+            "65283:0": self.on_invite_message,
         }
 
         self.notif_methods = {
             "53": self.on_member_set_you_host,
             "67": self.on_member_set_you_cohost,
-            "68": self.on_member_remove_you_cohost
+            "68": self.on_member_remove_you_cohost,
         }
 
         self.topics = {
@@ -88,7 +87,7 @@ class Callbacks:
             "users-start-typing-at": self.on_user_typing_start,
             "users-end-typing-at": self.on_user_typing_end,
             "users-start-recording-at": self.on_voice_chat_start,
-            "users-end-recording-at": self.on_voice_chat_end
+            "users-end-recording-at": self.on_voice_chat_end,
         }
 
     def _resolve_payload(self, data):
@@ -100,86 +99,201 @@ class Callbacks:
         return self.chat_methods.get(key, self.default)(data)
 
     def _resolve_topics(self, data):
-        key = str(data['o'].get('topic', 0)).split(":")[2]
+        key = str(data["o"].get("topic", 0)).split(":")[2]
         return self.topics.get(key, self.default)(data)
 
     def resolve(self, data):
         data = json.loads(data)
         return self.methods.get(data["t"], self.default)(data)
 
-    def call(self, type, data):
-        if type in self.handlers:
-            for handler in self.handlers[type]:
+    def call(self, callType, data):
+        if callType in self.handlers:
+            for handler in self.handlers[callType]:
                 handler(data)
 
-    def event(self, type):
+    def event(self, eventType):
         def registerHandler(handler):
-            if type in self.handlers:
-                self.handlers[type].append(handler)
+            if eventType in self.handlers:
+                self.handlers[eventType].append(handler)
             else:
-                self.handlers[type] = [handler]
+                self.handlers[eventType] = [handler]
             return handler
 
         return registerHandler
-    
-    def setCall(self, name, data): self.call(name, Event(data["o"]).Event)
-    def on_member_set_you_host(self, data): self.call(getframe(0).f_code.co_name, Payload(data["o"]).Payload)
-    def on_member_remove_you_cohost(self, data): self.call(getframe(0).f_code.co_name, Payload(data["o"]).Payload)
-    def on_member_set_you_cohost(self, data): self.call(getframe(0).f_code.co_name, Payload(data["o"]).Payload)
-    def on_text_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_image_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_youtube_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_strike_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_sticker_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def TYPE_USER_SHARE_EXURL(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def TYPE_USER_SHARE_USER(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_not_answered(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_not_cancelled(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_not_declined(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_video_chat_not_answered(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_video_chat_not_cancelled(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_video_chat_not_declined(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_avatar_chat_not_answered(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_avatar_chat_not_cancelled(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_avatar_chat_not_declined(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_delete_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_group_member_join(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_group_member_leave(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_invite(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_background_changed(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_title_changed(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_icon_changed(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_start(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_video_chat_start(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_avatar_chat_start(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_end(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_video_chat_end(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_avatar_chat_end(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_content_changed(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_screen_room_start(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_screen_room_end(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_host_transfered(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_text_message_force_removed(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_removed_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_text_message_removed_by_admin(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_tip(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_pin_announcement(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_permission_open_to_everyone(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_permission_invited_and_requested(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_voice_chat_permission_invite_only(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_view_only_enabled(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_view_only_disabled(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_unpin_announcement(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_tipping_enabled(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_chat_tipping_disabled(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_timestamp_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_welcome_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_invite_message(self, data): self.setCall(getframe(0).f_code.co_name, data)
-    def on_user_typing_start(self, data): self.call(getframe(0).f_code.co_name, UsersActions(data).UsersActions)
-    def on_user_typing_end(self, data): self.call(getframe(0).f_code.co_name, UsersActions(data).UsersActions)
-    def on_online_users_update(self, data): self.call(getframe(0).f_code.co_name, UsersActions(data).UsersActions)
-    def default(self, data): self.call(getframe(0).f_code.co_name, data)
+
+    def setCall(self, name, data):
+        self.call(name, Event(data["o"]).Event)
+
+    def on_member_set_you_host(self, data):
+        self.call(getframe(0).f_code.co_name, Payload(data["o"]).Payload)
+
+    def on_member_remove_you_cohost(self, data):
+        self.call(getframe(0).f_code.co_name, Payload(data["o"]).Payload)
+
+    def on_member_set_you_cohost(self, data):
+        self.call(getframe(0).f_code.co_name, Payload(data["o"]).Payload)
+
+    def on_text_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_image_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_youtube_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_strike_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_sticker_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def TYPE_USER_SHARE_EXURL(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def TYPE_USER_SHARE_USER(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_not_answered(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_not_cancelled(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_not_declined(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_video_chat_not_answered(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_video_chat_not_cancelled(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_video_chat_not_declined(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_avatar_chat_not_answered(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_avatar_chat_not_cancelled(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_avatar_chat_not_declined(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_delete_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_group_member_join(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_group_member_leave(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_invite(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_background_changed(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_title_changed(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_icon_changed(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_start(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_video_chat_start(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_avatar_chat_start(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_end(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_video_chat_end(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_avatar_chat_end(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_content_changed(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_screen_room_start(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_screen_room_end(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_host_transfered(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_text_message_force_removed(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_removed_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_text_message_removed_by_admin(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_tip(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_pin_announcement(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_permission_open_to_everyone(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_permission_invited_and_requested(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_voice_chat_permission_invite_only(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_view_only_enabled(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_view_only_disabled(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_unpin_announcement(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_tipping_enabled(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_chat_tipping_disabled(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_timestamp_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_welcome_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_invite_message(self, data):
+        self.setCall(getframe(0).f_code.co_name, data)
+
+    def on_user_typing_start(self, data):
+        self.call(getframe(0).f_code.co_name, UsersActions(data).UsersActions)
+
+    def on_user_typing_end(self, data):
+        self.call(getframe(0).f_code.co_name, UsersActions(data).UsersActions)
+
+    def on_online_users_update(self, data):
+        self.call(getframe(0).f_code.co_name, UsersActions(data).UsersActions)
+
+    def default(self, data):
+        self.call(getframe(0).f_code.co_name, data)
 
 
 class SetAction:
@@ -212,9 +326,19 @@ class Actions:
         """
         Default Browsing
         """
-        SetAction(self.socket, {
-            "o": {"actions": ["Browsing"], "target": f"ndc://x{self.comId}/", "ndcId": int(self.comId),
-                  "params": {"duration": 27605}, "id": "363483"}, "t": 306}).start()
+        SetAction(
+            self.socket,
+            {
+                "o": {
+                    "actions": ["Browsing"],
+                    "target": f"ndc://x{self.comId}/",
+                    "ndcId": int(self.comId),
+                    "params": {"duration": 27605},
+                    "id": "363483",
+                },
+                "t": 306,
+            },
+        ).start()
 
     def Browsing(self, blogId: str = None, blogType: int = 0):
         """
@@ -238,9 +362,9 @@ class Actions:
                 "target": target,
                 "ndcId": int(self.comId),
                 "params": {"blogType": blogType},
-                "id": "363483"
+                "id": "363483",
             },
-            "t": 306
+            "t": 306,
         }
         self.setDefaultAction()
         return SetAction(self.socket, data)
@@ -265,11 +389,11 @@ class Actions:
                     "duration": 12800,
                     "membershipStatus": 1,
                     "threadType": threadType,
-                    "threadId": threadId
+                    "threadId": threadId,
                 },
-                "id": "1715976"
+                "id": "1715976",
             },
-            "t": 306
+            "t": 306,
         }
         # self.defaultData()
         return SetAction(self.socket, data)
@@ -287,9 +411,9 @@ class Actions:
                 "target": f"ndc://x{self.comId}/public-chats",
                 "ndcId": int(self.comId),
                 "params": {"duration": 859},
-                "id": "363483"
+                "id": "363483",
             },
-            "t": 306
+            "t": 306,
         }
         self.setDefaultAction()
         return SetAction(self.socket, data)
@@ -307,9 +431,9 @@ class Actions:
                 "target": f"ndc://x{self.comId}/leaderboards",
                 "ndcId": int(self.comId),
                 "params": {"duration": 859},
-                "id": "363483"
+                "id": "363483",
             },
-            "t": 306
+            "t": 306,
         }
         self.setDefaultAction()
         return SetAction(self.socket, data)
@@ -332,9 +456,9 @@ class Actions:
                 "target": target,
                 "ndcId": int(self.comId),
                 "params": params,
-                "id": "363483"
+                "id": "363483",
             },
-            "t": 306
+            "t": 306,
         }
         self.setDefaultAction()
         return SetAction(self.socket, data)
@@ -351,9 +475,9 @@ class WssClient:
                 "ndcId": int(comId),
                 "threadId": chatId,
                 "joinRole": joinType,
-                "id": "37549515"
+                "id": "37549515",
             },
-            "t": 112
+            "t": 112,
         }
         timer.sleep(2.2)
         self.wss.send(data)
@@ -373,9 +497,9 @@ class WssClient:
                 "threadId": chatId,
                 "joinRole": joinType,
                 "channelType": 5,
-                "id": "2154531"
+                "id": "2154531",
             },
-            "t": 108
+            "t": 108,
         }
         timer.sleep(2.2)
         self.wss.send(data)
@@ -394,9 +518,9 @@ class WssClient:
                 "ndcId": comId,
                 "threadId": chatId,
                 "joinRole": joinType,
-                "id": "2154531"
+                "id": "2154531",
             },
-            "t": 112
+            "t": 112,
         }
         timer.sleep(2.2)
         self.wss.send(data)
@@ -405,9 +529,9 @@ class WssClient:
                 "ndcId": comId,
                 "threadId": chatId,
                 "channelType": 1,
-                "id": "2154531"
+                "id": "2154531",
             },
-            "t": 108
+            "t": 108,
         }
         timer.sleep(2.2)
         self.wss.send(data)
@@ -426,9 +550,9 @@ class WssClient:
                 "ndcId": comId,
                 "threadId": chatId,
                 "joinRole": leaveType,
-                "id": "2154531"
+                "id": "2154531",
             },
-            "t": 112
+            "t": 112,
         }
         timer.sleep(2.2)
         self.wss.send(data)
@@ -446,9 +570,9 @@ class WssClient:
                 "ndcId": int(comId),
                 "threadId": chatId,
                 "joinRole": 2,
-                "id": "72446"
+                "id": "72446",
             },
-            "t": 112
+            "t": 112,
         }
         timer.sleep(2.2)
         self.wss.send(data)
@@ -459,9 +583,9 @@ class WssClient:
                 "ndcId": int(comId),
                 "threadId": chatId,
                 "joinRole": 1,
-                "id": "10335106"
+                "id": "10335106",
             },
-            "t": 112
+            "t": 112,
         }
         self.wss.send(data)
 
@@ -471,80 +595,34 @@ class WssClient:
                 "ndcId": int(comId),
                 "threadId": chatId,
                 "channelType": 5,
-                "id": "10335436"
+                "id": "10335436",
             },
-            "t": 108
+            "t": 108,
         }
         self.wss.send(data)
 
-    def videoPlayer(self, comId: str, chatId: str, path: str, title: str, background: str, duration: int):
-        self.actions(comId, chatId).Chatting().start()
-        self.threadJoin(comId, chatId)
-        self.channelJoin(comId, chatId)
-        data = {
-            "o": {
-                "ndcId": int(comId),
-                "threadId": chatId,
-                "playlist": {
-                    "currentItemIndex": 0,
-                    "currentItemStatus": 1,
-                    "items": [{
-                        "author": None,
-                        "duration": duration,
-                        "isDone": False,
-                        "mediaList": [[100, background, None]],
-                        "title": title,
-                        "type": 1,
-                        "url": f"file://{path}"
-                    }]
-                },
-                "id": "3423239"
-            },
-            "t": 120
-        }
-        self.wss.send(data)
-        timer.sleep(2)
-        data["o"]["playlist"]["currentItemStatus"] = 2
-        data["o"]["playlist"]["items"][0]["isDone"] = True
-        self.wss.send(data)
-
-    def playVideo(self, comId: str, chatId: str, path: str, title: str, background: BinaryIO, duration: int):
-        """
-        Play Custom Video
-
-        **Parameters**
-            - **comId** : ID of the Community (str)
-            - **chatId** : ID of the Chat (str)
-            - **path** : Video Path | /storage/emulated/0/Download/video.mp4 (str)
-            - **title** : Video Title (str)
-            - **background** : Background of the video (BinaryIO)
-            - **duration** : length of the mp4/mp3 (int)
-        """
-        threading.Thread(target=self.videoPlayer,
-                         args=(comId, chatId, path, title, self.wss.uploadMedia(background, "image"), duration)).start()
-
     def GetUsersActions(self, comId: str = None, path: int = 0, chatId: str = None):
         """
-            Get users actions:
-            This functions gets certain socket actions happening
-            such as online users and users chatting
+        Get users actions:
+        This functions gets certain socket actions happening
+        such as online users and users chatting
 
-            Parameters
-                ----------
-                comId : int
-                    the community id -required
+        Parameters
+            ----------
+            comId : int
+                the community id -required
 
-                path : int
-                    takes an intger >= 0 and <= 5 each one sends a certain action
-                    not required -set by default to 0 // users-chatting
+            path : int
+                takes an intger >= 0 and <= 5 each one sends a certain action
+                not required -set by default to 0 // users-chatting
 
-                chatId : str
-                    the chatId used in certain actions such as 'users-start-typing-at -Optional
+            chatId : str
+                the chatId used in certain actions such as 'users-start-typing-at -Optional
 
-                Returns
-                ----------
-            A Class property if there is a new message it will contain a userProfileList
-            you can explore 'UsersActions' in objects file  
+            Returns
+            ----------
+        A Class property if there is a new message it will contain a userProfileList
+        you can explore 'UsersActions' in objects file
         """
         acts = {
             0: "users-chatting",
@@ -552,7 +630,7 @@ class WssClient:
             2: "users-start-typing-at",
             3: "users-end-typing-at",
             4: "users-start-recording-at",
-            5: "users-start-recording-at"
+            5: "users-start-recording-at",
         }
 
         if chatId:
@@ -564,9 +642,9 @@ class WssClient:
             "o": {
                 "ndcId": int(comId) if comId else 0,
                 "topic": f"ndtopic:x{comId}:{topic}",
-                "id": "4538416"
+                "id": "4538416",
             },
-            "t": 300
+            "t": 300,
         }
 
         timer.sleep(2.2)
@@ -581,11 +659,10 @@ class WssClient:
         return UsersActions(data={}).UsersActions
 
     def actions(self, comId: str, chatId: str):
-        # threading.Thread(target=self.wss.sendWebActive, args=(comId,)).start()
         return Actions(self.wss, comId, chatId)
 
 
-class Wss(Callbacks, WssClient):
+class Wss(Callbacks, WssClient, Headers):
     def __init__(self, client, trace: bool = False):
 
         self.trace = trace
@@ -594,9 +671,10 @@ class Wss(Callbacks, WssClient):
         self.client = client
         self.isOpened = False
 
+        Headers.__init__(self)
         Callbacks.__init__(self)
         WssClient.__init__(self, self)
-        
+
         self.narvi = "https://service.narvii.com/api/v1/"
         self.socket_url = "wss://ws1.narvii.com"
         self.lastMessage = {}
@@ -604,68 +682,57 @@ class Wss(Callbacks, WssClient):
 
     def onOpen(self, *args):
         self.isOpened = True
-        if self.trace: print('[ON-OPEN] Sockets are open')
+        if self.trace:
+            print("[ON-OPEN] Sockets are open")
 
     def onClose(self, *args):
         self.isOpened = False
-        if self.trace: print('[ON-CLOSE] Sockets are closed')
+        if self.trace:
+            print("[ON-CLOSE] Sockets are closed")
 
     def send(self, data):
         self.socket.send(json.dumps(data))
 
     def receive(self):
-        if self.trace: print('[RECEIVE] returning last message')
+        if self.trace:
+            print("[RECEIVE] returning last message")
         return self.lastMessage
 
     def on_message(self, ws, data):
         self.lastMessage = json.loads(data)
         self.resolve(data)
-        if self.trace: print('[ON-MESSAGE] Received a message . . .')
+        if self.trace:
+            print("[ON-MESSAGE] Received a message . . .")
 
     def launch(self):
         final = f"{self.client.deviceId}|{int(timer.time() * 1000)}"
         self.headers = {
             "NDCDEVICEID": self.client.deviceId,
             "NDCAUTH": self.client.sid,
-            "NDC-MSG-SIG": util.generateSig(data=final)}
-        self.socket = websocket.WebSocketApp(f"{self.socket_url}/?signbody={final.replace('|', '%7C')}",
-                                             on_message=self.on_message,
-                                             on_close=self.onClose,
-                                             on_open=self.onOpen,
-                                             header=self.headers)
-        if self.trace: print('[LAUNCH] Sockets starting . . . ')
-        threading.Thread(target=self.socket.run_forever, kwargs={"ping_interval": 60}).start()
+            "NDC-MSG-SIG": util.generateSig(data=final),
+        }
+        
+        self.socket = websocket.WebSocketApp(
+            f"{self.socket_url}/?signbody={final.replace('|', '%7C')}",
+            on_message=self.on_message,
+            on_close=self.onClose,
+            on_open=self.onOpen,
+            header=self.headers,
+        )
+
+        if self.trace:
+            print("[LAUNCH] Sockets starting . . . ")
+        threading.Thread(
+            target=self.socket.run_forever, kwargs={"ping_interval": 60}
+        ).start()
 
     def close(self):
         self.socket.close()
-        if self.trace: print('[CLOSE] closing socket . . .')
+        if self.trace:
+            print("[CLOSE] closing socket . . .")
         timer.sleep(1.5)
 
-    def status(self):
-        print('\nSockets are OPEN\n') if self.isOpened else print('\nSockets are CLOSED\n')
-
-    def uploadMedia(self, file: BinaryIO, fileType: str):
-        if fileType == "audio":
-            typee = "audio/aac"
-        elif fileType == "image":
-            typee = "image/jpg"
-        else:
-            raise TypeError("[i] Report this error in Discord Server as [15:0]")
-
-        data = file.read()
-        headers = self.headers
-        headers["content-type"] = typee
-        headers["content-length"] = str(len(data))
-
-        response = requests.post(f"{self.narvi}/g/s/media/upload", data=data, headers=headers)
-        if response.json()["api:statuscode"] != 0:
-            return CheckExceptions(response.json())
-        return response.json()["mediaValue"]
-
-    def sendWebActive(self, comId: str):
-        data = {"ndcId": comId}
-
-        response = requests.post(util.webApi("/community/stats/web-user-active-time"), json=data, headers=headers.Headers().web_headers)
-        if response.status_code != 200: return CheckExceptions(response.json())
-
-        return response.json()
+    def socket_status(self):
+        print("\nSockets are OPEN\n") if self.isOpened else print(
+            "\nSockets are CLOSED\n"
+        )
